// Copyright 2005, Google Inc.
// 
// Operations on cookies that are common across our pages.
//
// Original Author: Pal Takacsi-Nagy (pal@google.com)


/**
 * Sets a Cookie with the given name and value.
 *
 * name       Name of the cookie
 * value      Value of the cookie
 * [expires]  Expiration date of the cookie (default: end of current session)
 * [path]     Path where the cookie is valid (default: path of calling document)
 * [domain]   Domain where the cookie is valid
 *              (default: domain of calling document)
 * [secure]   Boolean value indicating if the cookie transmission requires a
 *              secure transmission
 */
function setCookie(name, value, domain, expires, path, secure) {
    document.cookie = name + "=" + escape(value) +
        ((expires) ? "; expires=" + expires.toGMTString() : "") +
        ((path) ? "; path=" + path : "") +
        ((domain) ? "; domain=" + domain : "") +
        ((secure) ? "; secure" : "");
}

/**
 * Gets the value of the specified cookie.
 *
 * name  Name of the desired cookie.
 *
 * Returns a string containing value of specified cookie,
 *   or null if cookie does not exist.
 */
function getCookie(name) {
    var dc = document.cookie;
    var prefix = name + "=";
    var begin = dc.indexOf("; " + prefix);

    if (begin == -1) {
        begin = dc.indexOf(prefix);
        if (begin != 0) return null;
    } else {
        begin += 2;
    }

    var end = document.cookie.indexOf(";", begin);

    if (end == -1) {
        end = dc.length;
    }

    return unescape(dc.substring(begin + prefix.length, end));
}

/**
 * Logs cookie related text.  
 * blogID    id of the blog to pass as query parameter to log-message.g
 * text      text to be logged.
 */
function logCookieText(blogID, text) {
  var req = null;

  if (window.XMLHttpRequest) {
    var r = new XMLHttpRequest();

    // some older version of mozilla had xmlhttprequest, but not
    // readystate. no reason to waste effort on them.
    if (r.readyState != null && typeof(r.onreadystatechange) != 'undefined') {
      req = r;
    }
  } else {
    try {
      req = new ActiveXObject("Microsoft.XMLHTTP");
    } catch (e) {
      // do nothing because we just fall thorough to bottom...
    }
  }
  if (req != null) {
    req.open("GET", "/log-message.g?blogID=" + blogID + "&msg=" + escape(text));
    req.send(null);
  }
}

